import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _JSXStyle from "styled-jsx/style";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from "react";
import "./monkey-patch-calendar-day";
import "./monkey-patch-day-picker";
import { ArgumentError } from "@orbit-ui/react-components-shared";
import { ChevronIcon } from "@orbit-ui/icons";
import { NAVIGATION_ROLE } from "./element-roles";
import { PureComponent, cloneElement } from "react";
import { bool, func, node, number, oneOfType, string } from "prop-types";
import { isFunction, isNil } from "lodash";
import { momentObj as momentType } from "react-moment-proptypes";
import moment from "moment";
const PHRASES = {
  chooseAvailableStartDate: ({
    date
  }) => "Choose ".concat(date, "."),
  chooseAvailableEndDate: ({
    date
  }) => "Choose ".concat(date, ".")
};
export class DatePickerCalendar extends PureComponent {
  constructor(...args) {
    super(...args);

    this.isDayBlocked = day => {
      const {
        minDate,
        maxDate
      } = this.props;

      if (!isNil(minDate) && !isNil(maxDate)) {
        return day.isBefore(minDate, "day") || day.isAfter(maxDate, "day");
      }

      if (!isNil(minDate)) {
        return day.isBefore(minDate, "day");
      }

      if (!isNil(maxDate)) {
        return day.isAfter(maxDate, "day");
      }

      return false;
    };

    this.isMonthBlocked = month => {
      const {
        minDate,
        maxDate
      } = this.props;

      if (!isNil(minDate) || !isNil(maxDate)) {
        const firstDay = moment(month).startOf("month");
        const lastDay = moment(month).endOf("month");
        return this.isDayBlocked(firstDay) && this.isDayBlocked(lastDay);
      }

      return false;
    };

    this.getInitialVisibleMonth = () => {
      const {
        initialDate,
        initialVisibleMonth,
        numberOfMonths
      } = this.props;

      if (!isNil(initialVisibleMonth)) {
        if (isFunction(initialVisibleMonth)) {
          return initialVisibleMonth(this.props);
        }

        return initialVisibleMonth;
      } else if (numberOfMonths > 1) {
        return this.getInitialVisibleMonthFromDates();
      }

      return initialDate;
    };
  }

  componentDidMount() {
    const {
      minDate,
      maxDate
    } = this.props;

    if (!isNil(minDate) && !isNil(maxDate)) {
      if (minDate.isSameOrAfter(maxDate)) {
        throw new ArgumentError("DatePicker - \"minDate\" must be before \"maxDate\".");
      }
    }
  }

  getInitialVisibleMonthFromDates() {
    const {
      initialDate
    } = this.props;
    const initialMonth = initialDate;
    const nextMonth = moment(initialMonth).add(1, "months");

    if (this.isMonthBlocked(nextMonth)) {
      // When the next month is blocked, show the previous and current months instead of the current and next months.
      const previousMonth = moment(initialMonth).subtract(1, "months");

      if (!this.isMonthBlocked(previousMonth)) {
        return previousMonth;
      }
    }

    return initialMonth;
  }

  getCssClasses() {
    const {
      className
    } = this.props;
    const defaultClasses = "calendar flex z-2";
    return isNil(className) ? defaultClasses : "".concat(defaultClasses, " ").concat(className);
  } // Temporary fix until the following PR is merged: https://github.com/airbnb/react-dates/pull/1672


  getNavigationRestrictionProps() {
    const {
      minDate,
      maxDate,
      temporarySingleDatePickerFlag
    } = this.props;

    if (!temporarySingleDatePickerFlag) {
      return {
        minDate,
        maxDate
      };
    }

    return {};
  }

  renderNavPrev() {
    const {
      navPrevIcon
    } = this.props;
    return React.createElement("div", {
      tabIndex: "0",
      className: "flex",
      "data-role": NAVIGATION_ROLE
    }, navPrevIcon);
  }

  renderNavNext() {
    const {
      navNextIcon
    } = this.props;
    return React.createElement("div", {
      tabIndex: "0",
      className: "flex",
      "data-role": NAVIGATION_ROLE
    }, navNextIcon);
  }

  renderCalendar() {
    const {
      calendar,
      minDate,
      maxDate,
      numberOfMonths
    } = this.props;
    return cloneElement(calendar, _objectSpread({}, this.getNavigationRestrictionProps(), {
      navPrev: this.renderNavPrev(),
      navNext: this.renderNavNext(),
      isDayBlocked: !isNil(minDate) || !isNil(maxDate) ? this.isDayBlocked : undefined,
      initialVisibleMonth: this.getInitialVisibleMonth,
      numberOfMonths: numberOfMonths,
      phrases: PHRASES,
      transitionDuration: 0,
      noBorder: true,
      keepOpenOnDateSelect: true,
      hideKeyboardShortcutsPanel: true
    }));
  }

  render() {
    const {
      buttons,
      leftContent
    } = this.props;
    return React.createElement("div", {
      className: "jsx-1423821426" + " " + (this.getCssClasses() || "")
    }, leftContent, React.createElement("div", {
      className: "jsx-1423821426" + " " + "flex flex-column"
    }, this.renderCalendar(), buttons), React.createElement(_JSXStyle, {
      id: "1423821426"
    }, [".calendar.jsx-1423821426{border-radius:var(--scale-alpha);box-shadow:var(--shadow-5);background-color:var(--white);}", ".calendar.jsx-1423821426 .CalendarMonth_table{margin-top:var(--scale-bravo);}", ".calendar.jsx-1423821426 .CalendarDay__default{border:none;background-color:var(--white);color:var(--marine-700);font-size:1rem;}", ".calendar.jsx-1423821426 .DayPicker__horizontal{background-color:var(--white);}", ".calendar.jsx-1423821426 .CalendarMonth{background-color:var(--white);}", ".calendar.jsx-1423821426 .CalendarDay__selected{background:var(--primary-500);color:var(--white);}", ".calendar.jsx-1423821426 .CalendarMonthGrid{background-color:var(--white);}", ".calendar.jsx-1423821426 .CalendarDay__selected_span{background:var(--primary-50);}", ".calendar.jsx-1423821426 .CalendarDay__hovered_span{background:var(--primary-50);}", ".calendar.jsx-1423821426 .CalendarMonth_caption{font-size:24px;color:var(--marine-500);padding-top:1.25rem;padding-bottom:2.5rem;line-height:1;}", ".calendar.jsx-1423821426 .DayPickerNavigation_button__default{border:0;}", ".calendar.jsx-1423821426 .CalendarDay__blocked_calendar{background:var(--transparent);color:var(--cloud-400);}", ".calendar.jsx-1423821426 .DayPickerNavigation{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-webkit-justify-content:space-between;-ms-flex-pack:justify;justify-content:space-between;padding:0 24px;}", ".calendar.jsx-1423821426 .DayPickerNavigation_button{margin-top:24px;}", ".calendar.jsx-1423821426 .DayPickerNavigation_button__horizontalDefault{padding:0;}", ".calendar.jsx-1423821426 .DayPickerNavigation_button__disabled{border:0;}", ".calendar.jsx-1423821426 .DayPicker_weekHeader_li small{font-size:0.875rem;color:var(--cloud-900);}", ".calendar.jsx-1423821426 .CalendarDay__default:hover,.calendar.jsx-1423821426 .CalendarDay__default:focus{background:var(--cloud-100);}", ".calendar.jsx-1423821426 .CalendarDay__default:focus{outline:none;}", ".calendar.jsx-1423821426 .DayPickerNavigation_button:focus{outline:none;}", ".calendar.jsx-1423821426 .CalendarDay__blocked_calendar:hover,.calendar.jsx-1423821426 .CalendarDay__blocked_calendar:focus{background:var(--transparent);color:var(--cloud-400);}", ".calendar.jsx-1423821426 .CalendarDay__selected:hover,.calendar.jsx-1423821426 .CalendarDay__selected:active{background:var(--primary-500);}", ".calendar.jsx-1423821426 .CalendarDay__selected_span:hover,.calendar.jsx-1423821426 .CalendarDay__selected_span:active{background:var(--primary-50);}", ".calendar.jsx-1423821426 .CalendarDay__default.CalendarDay__selected:focus{background:var(--primary-500);color:var(--white);}", ".calendar.jsx-1423821426 .CalendarDay__blocked_calendar.CalendarDay__selected{background:var(--primary-500);color:var(--white);opacity:0.6;}", ".calendar.jsx-1423821426 .CalendarDay__blocked_calendar.CalendarDay__selected_span{background:var(--primary-50);opacity:0.6;}", ".calendar.jsx-1423821426 .DayPickerNavigation_button__disabled path{fill:var(--cloud-100);}"]));
  }

}
DatePickerCalendar.propTypes = {
  calendar: node.isRequired,
  buttons: node.isRequired,
  leftContent: node,
  minDate: momentType,
  maxDate: momentType,
  initialDate: momentType.isRequired,
  initialVisibleMonth: oneOfType([momentType, func]),
  numberOfMonths: number,
  navPrevIcon: node,
  navNextIcon: node,
  className: string,
  temporarySingleDatePickerFlag: bool
};
DatePickerCalendar.defaultProps = {
  navPrevIcon: React.createElement(ChevronIcon, {
    className: "w4 h4 rotate-180 fill-marine-500"
  }),
  navNextIcon: React.createElement(ChevronIcon, {
    className: "w4 h4 fill-marine-500"
  }),
  temporarySingleDatePickerFlag: false
};