import React from "react";
import { DatePickerTextboxInput } from "../date-picker-textbox-input";
import { PureComponent, forwardRef } from "react";
import { bool, func, node, object, string } from "prop-types";
import { isNil } from "lodash";
import { momentObj as momentType } from "react-moment-proptypes";
import { useHandlerProxy } from "@orbit-ui/react-components-shared";

class SingleDatePickerInputInner extends PureComponent {
  constructor(...args) {
    super(...args);
    this.handleOpen = useHandlerProxy(this, "onOpen", false);
    this.handleClose = useHandlerProxy(this, "onClose");
    this.handleSizeChange = useHandlerProxy(this, "onSizeChange", false);
    this.handleClear = useHandlerProxy(this, "onClear", false);
    this.handleClick = useHandlerProxy(this, "onClick");
    this.handleKeyDown = useHandlerProxy(this, "onKeyDown");
    this.handleFocus = useHandlerProxy(this, "onFocus");
    this.handleBlur = useHandlerProxy(this, "onBlur");
  }

  getValue() {
    const {
      date,
      dateFormat
    } = this.props;

    if (!isNil(date)) {
      return date.format(dateFormat);
    }

    return "";
  }

  render() {
    const {
      allowClear,
      placeholder,
      icon,
      clearIcon,
      disabledIcon,
      disabled,
      open,
      className,
      inputRef
    } = this.props;
    return React.createElement(DatePickerTextboxInput, {
      value: this.getValue(),
      onOpen: this.handleOpen,
      onClose: this.handleClose,
      onSizeChange: this.handleSizeChange,
      onClear: this.handleClear,
      onClick: this.handleClick,
      onKeyDown: this.handleKeyDown,
      onFocus: this.handleFocus,
      onBlur: this.handleBlur,
      allowClear: allowClear,
      placeholder: placeholder,
      icon: icon,
      clearIcon: clearIcon,
      disabledIcon: disabledIcon,
      disabled: disabled,
      open: open,
      className: className,
      ref: inputRef
    });
  }

}

SingleDatePickerInputInner.propTypes = {
  date: momentType,
  // eslint-disable-next-line react/no-unused-prop-types
  onOpen: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onClose: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onSizeChange: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onClear: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onClick: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onKeyDown: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onFocus: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onBlur: func,
  allowClear: bool,
  placeholder: string,
  dateFormat: string,
  icon: node,
  clearIcon: node,
  disabledIcon: node,
  disabled: bool,
  open: bool,
  className: string,
  inputRef: object
};
export const SingleDatePickerInput = forwardRef((props, ref) => React.createElement(SingleDatePickerInputInner, Object.assign({}, props, {
  inputRef: ref
})));