import React from "react";
import { Button, Ref } from "semantic-ui-react";
import { KEYS, useHandlerProxy } from "@orbit-ui/react-components-shared";
import { PureComponent, createRef } from "react";
import { bool, func, node, string } from "prop-types";
import { isNil } from "lodash";
export class MultiSelectDropdownTrigger extends PureComponent {
  constructor(...args) {
    super(...args);
    this._buttonRef = createRef();
    this.handleFocus = useHandlerProxy(this, "onFocus");
    this.handleBlur = useHandlerProxy(this, "onBlur");

    this.handleClick = event => {
      const {
        onClick,
        onOpen,
        onClose,
        open,
        disabled
      } = this.props;

      if (!isNil(onClick)) {
        onClick(event, this.props);
      }

      if (!disabled) {
        if (!open) {
          onOpen(event, this.props);
        } else {
          onClose(event, this.props);
        }
      }
    };

    this.handleKeyDown = event => {
      const {
        onKeyDown,
        onOpen,
        open,
        disabled
      } = this.props;

      if (!isNil(onKeyDown)) {
        onKeyDown(event, this.props);
      }

      const key = event.keyCode;

      if (key === KEYS.space) {
        event.preventDefault();

        if (!disabled) {
          if (!open) {
            onOpen(event, this.props);
          }
        }
      }
    };
  }

  getClasses() {
    const {
      className
    } = this.props;
    const defaultClasses = "tall";
    return isNil(className) ? defaultClasses : "".concat(defaultClasses, " ").concat(className);
  }

  renderIcon() {
    const {
      icon,
      disabledIcon,
      disabled
    } = this.props;
    return disabled ? disabledIcon : icon;
  }

  render() {
    const {
      text,
      disabled
    } = this.props;
    return React.createElement("div", {
      className: "mr2 mb2"
    }, React.createElement(Ref, {
      innerRef: this._buttonRef
    }, React.createElement(Button, {
      onClick: this.handleClick,
      onKeyDown: this.handleKeyDown,
      onFocus: this.handleFocus,
      onBlur: this.handleBlur,
      secondary: true,
      className: this.getClasses(),
      disabled: disabled,
      tabIndex: disabled ? "-1" : "0",
      type: "button"
    }, text, " ", this.renderIcon())));
  } // This function is part of the component external API.


  focus() {
    this._buttonRef.current.focus();
  } // This function is part of the component external API.


  isElement(element) {
    return this._buttonRef.current === element;
  }

}
MultiSelectDropdownTrigger.propTypes = {
  text: string,
  icon: node,
  disabledIcon: node,
  // eslint-disable-next-line react/no-unused-prop-types
  onClick: func,
  onKeyDown: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onFocus: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onBlur: func,
  onOpen: func,
  onClose: func,
  open: bool,
  disabled: bool,
  className: string
};