import React from "react";
import { Button, Label } from "semantic-ui-react";
import { CancelIcon } from "@orbit-ui/icons";
import { ITEM_SHAPE } from "./items";
import { PureComponent } from "react";
import { arrayOf, bool, func, shape, string } from "prop-types";
import { isNil } from "lodash";
import cx from "classnames";

function defaultItemRenderer(item, {
  disabled,
  onRemove
}) {
  return React.createElement(Label, {
    basic: true,
    className: cx("large", {
      icon: !disabled
    }),
    disabled: disabled
  }, item.text, !disabled ? React.createElement(Button, {
    circular: true,
    size: "mini",
    icon: true,
    className: "transparent",
    onClick: onRemove,
    type: "button"
  }, React.createElement(CancelIcon, {
    className: "h3 w3"
  })) : null);
}

class MultiSelectSelectedItem extends PureComponent {
  constructor(...args) {
    super(...args);

    this.handleRemove = event => {
      const {
        item,
        onRemove
      } = this.props;
      onRemove(event, item, this.props);
    };
  }

  getClasses() {
    const {
      className
    } = this.props;
    const defaultClasses = "mr2 mb2";
    return isNil(className) ? defaultClasses : "".concat(defaultClasses, " ").concat(className);
  }

  render() {
    const {
      item,
      itemRenderer,
      disabled
    } = this.props;
    return React.createElement("div", {
      className: this.getClasses()
    }, itemRenderer(item, {
      disabled: disabled,
      onRemove: this.handleRemove
    }));
  }

}

MultiSelectSelectedItem.propTypes = {
  item: shape(ITEM_SHAPE).isRequired,
  itemRenderer: func,
  onRemove: func.isRequired,
  disabled: bool,
  className: string
};
export class MultiSelectSelectedItems extends PureComponent {
  constructor(...args) {
    super(...args);

    this.handleRemoveSelectedItem = (event, item) => {
      const {
        onRemoveSelectedItem
      } = this.props;
      onRemoveSelectedItem(event, item);
    };
  }

  renderItems() {
    const {
      items,
      itemRenderer,
      disabled,
      className
    } = this.props;
    return items.map(x => {
      return React.createElement(MultiSelectSelectedItem, {
        item: x,
        itemRenderer: itemRenderer,
        onRemove: this.handleRemoveSelectedItem,
        key: x.value,
        disabled: disabled,
        className: className
      });
    });
  }

  render() {
    const {
      items
    } = this.props;

    if (items.length === 0) {
      return null;
    }

    return React.createElement(React.Fragment, null, this.renderItems());
  }

}
MultiSelectSelectedItems.propTypes = {
  items: arrayOf(shape(ITEM_SHAPE)),
  itemRenderer: func,
  onRemoveSelectedItem: func,
  disabled: bool,
  className: string
};
MultiSelectSelectedItems.defaultProps = {
  itemRenderer: defaultItemRenderer
};