import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from "react";
import { ArgumentError, AutoControlledPureComponent, DOMEventListener, KEYS, getAutoControlledStateFromProps } from "@orbit-ui/react-components-shared";
import { BOTTOM_LEFT, POSITIONS, isBottom, isCenter, isLeft, isRight, isTop } from "./positions";
import { FadeIn } from "./fade-in";
import { arrayOf, bool, func, node, oneOf, string } from "prop-types";
import { cloneElement, createRef } from "react";
import { isNil } from "lodash";

function fadeInAnimationRenderer(open, renderContent) {
  return React.createElement(FadeIn, {
    active: open
  }, renderContent());
}

export class Popup extends AutoControlledPureComponent {
  constructor(...args) {
    super(...args);
    this.state = {
      open: false,
      triggerHeight: 0
    };
    this._hasFocus = false;
    this._triggerRef = createRef();
    this._containerRef = createRef();

    this.handleDocumentKeyDown = event => {
      const {
        onDocumentKeyDown
      } = this.props;

      if (event.keyCode === KEYS.esc) {
        this.close(event);
      }

      if (!isNil(onDocumentKeyDown)) {
        onDocumentKeyDown(event, this.props);
      }
    };

    this.handleTriggerSizeChange = ({
      height
    }) => {
      this.setState({
        triggerHeight: height
      });
    };

    this.handleTriggerOpen = event => {
      const {
        open
      } = this.state;

      if (!open) {
        this.open(event);
      }
    };

    this.handleTriggerClose = event => {
      const {
        open
      } = this.state;

      if (open) {
        this.close(event);
      }
    };

    this.handleFocus = event => {
      const {
        onFocus
      } = this.props;
      this._hasFocus = true;

      if (!isNil(onFocus)) {
        onFocus(event, this.props);
      }
    };

    this.handleBlur = event => {
      const {
        onBlur,
        closeOnBlur
      } = this.props;
      const {
        open
      } = this.state;
      this._hasFocus = false;

      if (open) {
        if (closeOnBlur) {
          event.persist(); // The check is delayed because between leaving the old element and entering the new element the active element will always be the document/body itself.

          setTimeout(() => {
            if (!this._hasFocus) {
              this.close(event);
            }
          }, 0);
        }
      }

      if (!isNil(onBlur)) {
        onBlur(event, this.props);
      }
    };

    this.handleOutsideClick = event => {
      const {
        onOutsideClick,
        closeOnOutsideClick
      } = this.props;

      if (!this._containerRef.current.contains(event.target)) {
        if (closeOnOutsideClick) {
          this.close(event);
        }

        if (!isNil(onOutsideClick)) {
          onOutsideClick(event, this.props);
        }
      }
    };

    this.renderPopup = () => {
      const {
        children
      } = this.props;
      const {
        open
      } = this.state;

      if (!open) {
        return React.createElement(React.Fragment, null);
      }

      return React.createElement("div", {
        style: _objectSpread({
          position: "absolute",
          zIndex: 10
        }, this.getPositioningStyle())
      }, children);
    };
  }

  static getDerivedStateFromProps(props, state) {
    return getAutoControlledStateFromProps(props, state, Popup.autoControlledProps);
  }

  componentDidMount() {
    const {
      open
    } = this.state;

    if (open) {
      this.focusTrigger();
    }
  }

  componentDidUpdate(prevProps) {
    const {
      open,
      closeOnBlur,
      closeOnOutsideClick
    } = this.props;

    if (closeOnBlur && closeOnOutsideClick) {
      throw new ArgumentError("Popup - The \"closeOnBlur\" and \"closeOnOutsideClick\" props cannot be both \"true\".");
    }

    if (open !== prevProps.open) {
      if (!open) {
        this.focusTrigger();
      }
    }
  }

  getPositioningStyle() {
    const {
      position,
      offsets
    } = this.props;
    const {
      triggerHeight
    } = this.state;
    const style = {};
    const translates = [];

    if (isLeft(position)) {
      style.left = "0px";
      translates.push("translateX(".concat(offsets[0], ")"));
    } else if (isRight(position)) {
      style.right = "0px";
      translates.push("translateX(".concat(offsets[0], ")"));
    } else if (isCenter(position)) {
      style.left = "50%";
      translates.push("translateX(calc(-50% + ".concat(offsets[0], "))"));
    }

    if (isBottom(position)) {
      style.top = "".concat(triggerHeight, "px");
      translates.push("translateY(".concat(offsets[1], ")"));
    } else if (isTop(position)) {
      style.bottom = "".concat(triggerHeight, "px");
      translates.push("translateY(-".concat(offsets[1].startsWith("-") ? offsets[1].substring(1) : offsets[1], ")"));
    }

    if (translates.length !== 0) {
      style.transform = translates.join(" ");
    }

    return style;
  }

  getCssClasses() {
    const {
      className
    } = this.props;
    const defaultClasses = "relative";
    return isNil(className) ? defaultClasses : "".concat(defaultClasses, " ").concat(className);
  }

  open(event) {
    const {
      onVisibilityChange
    } = this.props;
    this.trySetAutoControlledStateValue({
      open: true
    });

    if (!isNil(onVisibilityChange)) {
      onVisibilityChange(event, true, this.props);
    }
  }

  close(event) {
    const {
      onVisibilityChange
    } = this.props;
    this.trySetAutoControlledStateValue({
      open: false
    });

    if (!isNil(onVisibilityChange)) {
      onVisibilityChange(event, false, this.props);
    }

    this.focusTrigger();
  }

  focusTrigger() {
    setTimeout(() => {
      if (!isNil(this._triggerRef.current)) {
        this._triggerRef.current.focus();
      }
    }, 0);
  }

  renderTrigger() {
    const {
      trigger
    } = this.props;
    const {
      open
    } = this.state;
    return cloneElement(trigger, {
      open: open,
      onSizeChange: this.handleTriggerSizeChange,
      onOpen: this.handleTriggerOpen,
      onClose: this.handleTriggerClose,
      ref: this._triggerRef
    });
  }

  render() {
    const {
      animationRenderer
    } = this.props;
    const {
      open
    } = this.state;
    return React.createElement(React.Fragment, null, React.createElement("div", {
      // Can use focus and blur since the React implementation of those events is not standard to the specs and bubbles.
      // For more info: https://github.com/facebook/react/issues/6410
      onFocus: this.handleFocus,
      onBlur: this.handleBlur,
      className: this.getCssClasses(),
      tabIndex: "-1",
      ref: this._containerRef
    }, this.renderTrigger(), animationRenderer(open, this.renderPopup, this.props)), open ? [React.createElement(DOMEventListener, {
      name: "keydown",
      on: this.handleDocumentKeyDown,
      key: "0"
    }), React.createElement(DOMEventListener, {
      name: "click",
      on: this.handleOutsideClick,
      key: "1"
    })] : null);
  }

}
Popup.propTypes = {
  open: bool,
  defaultOpen: bool,
  trigger: node.isRequired,
  children: node.isRequired,
  position: oneOf(POSITIONS).isRequired,
  offsets: arrayOf(string),
  onVisibilityChange: func,
  onDocumentKeyDown: func,
  onFocus: func,
  onBlur: func,
  onOutsideClick: func,
  animationRenderer: func,
  closeOnBlur: bool,
  closeOnOutsideClick: bool,
  className: string
};
Popup.defaultProps = {
  position: BOTTOM_LEFT,
  offsets: ["0px", "0px"],
  animationRenderer: fadeInAnimationRenderer,
  closeOnBlur: true,
  closeOnOutsideClick: false
};
Popup.autoControlledProps = ["open"];